@@ -67,9 +67,9 @@ class Authorization:
             authenticationsdk.util.ExceptionAuth.log_exception(logger,
                                                                GlobalLabelParameters.FILE_NOT_FOUND + str(e.filename),
                                                                mconfig)
-        except WindowsError as e:
+        except OSError as e:
             authenticationsdk.util.ExceptionAuth.log_exception(logger,
-                                                               GlobalLabelParameters.FILE_NOT_FOUND + str(e.filename),
+                                                               GlobalLabelParameters.SYSTEM_ERROR + str(e.filename),
                                                                mconfig)
         except Exception as e:
             if "mac verify failure" in str(e):
